==> igniteui-angular-charts-18.1.1.tgz: package/esm5/lib/DomainChartPlotAreaPointerEventArgs.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, Point_$type, markType } from "igniteui-angular-core";
import { isNaN_ } from "igniteui-angular-core";
/**
 * @hidden
 */
var DomainChartPlotAreaPointerEventArgs = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DomainChartPlotAreaPointerEventArgs, _super);
    function DomainChartPlotAreaPointerEventArgs(a, b) {
        var _this = _super.call(this) || this;
        _this.b = { $type: Point_$type, x: NaN, y: NaN };
        _this._plotAreaPosition = null;
        _this.a = null;
        _this.a = a;
        _this.plotAreaPosition = b;
        return _this;
    }
    Object.defineProperty(DomainChartPlotAreaPointerEventArgs.prototype, "plotAreaPosition", {
        get: function () {
            return this._plotAreaPosition;
        },
        set: function (a) {
            this._plotAreaPosition = a;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DomainChartPlotAreaPointerEventArgs.prototype, "chartPosition", {
        get: function () {
            if (isNaN_(this.b.x) && isNaN_(this.b.y)) {
                this.b.x = this.plotAreaPosition.x - this.a.v0.left;
                this.b.y = this.plotAreaPosition.y - this.a.v0.top;
            }
            return this.b;
        },
        enumerable: false,
        configurable: true
    });
    DomainChartPlotAreaPointerEventArgs.$t = markType(DomainChartPlotAreaPointerEventArgs, 'DomainChartPlotAreaPointerEventArgs');
    return DomainChartPlotAreaPointerEventArgs;
}(Base));
export { DomainChartPlotAreaPointerEventArgs };

==> igniteui-angular-charts-18.2.0.tgz: package/esm5/lib/DomainChartPlotAreaPointerEventArgs.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, Point_$type, markType } from "igniteui-angular-core";
import { isNaN_ } from "igniteui-angular-core";
/**
 * @hidden
 */
var DomainChartPlotAreaPointerEventArgs = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DomainChartPlotAreaPointerEventArgs, _super);
    function DomainChartPlotAreaPointerEventArgs(a, b) {
        var _this = _super.call(this) || this;
        _this.b = { $type: Point_$type, x: NaN, y: NaN };
        _this._plotAreaPosition = null;
        _this.a = null;
        _this.a = a;
        _this.plotAreaPosition = b;
        return _this;
    }
    Object.defineProperty(DomainChartPlotAreaPointerEventArgs.prototype, "plotAreaPosition", {
        get: function () {
            return this._plotAreaPosition;
        },
        set: function (a) {
            this._plotAreaPosition = a;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DomainChartPlotAreaPointerEventArgs.prototype, "chartPosition", {
        get: function () {
            if (isNaN_(this.b.x) && isNaN_(this.b.y)) {
                this.b.x = this.plotAreaPosition.x - this.a.wk.left;
                this.b.y = this.plotAreaPosition.y - this.a.wk.top;
            }
            return this.b;
        },
        enumerable: false,
        configurable: true
    });
    DomainChartPlotAreaPointerEventArgs.$t = markType(DomainChartPlotAreaPointerEventArgs, 'DomainChartPlotAreaPointerEventArgs');
    return DomainChartPlotAreaPointerEventArgs;
}(Base));
export { DomainChartPlotAreaPointerEventArgs };
